import React, { useState } from "react";
import { View, Text, Button, Alert, ScrollView, Linking } from "react-native";

export default function PatientConsentForm({ navigation, route }) {
  const [isConsentAgreed, setIsConsentAgreed] = useState(false);

  const handleAgree = () => {
    setIsConsentAgreed(true);
    navigation.navigate("PatientRegOne"); // Navigate to the next component after agreeing
  };

  const handleCancel = () => {
    Alert.alert(
      "Confirmation",
      "Are you sure you want to cancel?",
      [
        {
          text: "No",
          style: "cancel",
        },
        {
          text: "Yes",
          onPress: () => {
            // Close the app
            navigation.navigate("MainScreen");
          },
        },
      ],
      { cancelable: false }
    );
  };

  return (
    <ScrollView style={{ padding: 10, marginTop: 30 }}>
      <Text style={{ fontWeight: "bold", fontSize: 20 }}>
        Consent Form for EMMA Health Application
        {"\n"}
      </Text>
      <Text>
        Please read this consent form carefully before using the EMMA health
        application.
      </Text>
      <Text style={{ textDecorationLine: "underline" }}>{"\n"}Introduction:</Text>
      <Text>
        The EMMA (Emotional Mental Health Assistant) application is designed to
        track and manage personal details, emotional status, and mental health
        via chat. By using this application, you consent to the collection and
        secure storage of your data as described below.
      </Text>
      <Text style={{ textDecorationLine: "underline" }}>{"\n"}Data Collection:</Text>
      <Text>
        {"\n"}Personal Details: The EMMA app collects personal information such
        as your name, age, gender, and contact details. This information is used
        to personalize your experience and ensure accurate record-keeping.
      </Text>
      <Text>
        {"\n"}Emotional Status: The app collects data related to your emotional
        well-being, including mood fluctuations, stress levels, and general
        feelings. This information helps in understanding and managing your
        emotional health effectively.
      </Text>
      <Text>
        {"\n"}Mental Health: The app tracks and analyzes your mental health
        status based on the conversations you have with EMMA. This includes
        identifying patterns, identifying triggers, and providing insights for
        mental health management.
      </Text>
      <Text style={{ textDecorationLine: "underline" }}>{"\n"}Data Storage and Security:</Text>
      <Text>
        {"\n"}Data Encryption: All collected data will be properly encrypted to
        ensure its security and confidentiality.
      </Text>
      <Text>
        {"\n"}Stellar Blockchain: Your encrypted data will be securely stored in
        a public blockchain called Stellar. Stellar's blockchain technology
        provides an additional layer of data protection and immutability.
      </Text>
      <Text>
        {"\n"}Access Control: Your data will be accessible only to authorized
        individuals involved in the maintenance of the EMMA application. Strict
        access controls will be implemented to prevent unauthorized access.
      </Text>
      <Text style={{ textDecorationLine: "underline" }}>{"\n"}Purpose of Data Collection:</Text>
      <Text>
        {"\n"}User Control: The primary purpose of data collection is to empower
        you with control over your own health data. You will have the ability to
        manage access permissions and decide who can view or access your data.
      </Text>
      <Text>
        {"\n"}Mental Health History: The collected data can be used to generate
        a comprehensive mental health history for your benefit. This history may
        assist healthcare practitioners in understanding your mental health
        trends, improving diagnostic accuracy, and developing personalized
        treatment plans.
      </Text>
      {/* <Button title="Agree" onPress={handleAgree}/>
      <Button title="Cancel" onPress={handleCancel} /> */}

      <View style={{ marginTop: 10 }}>
        <Button title="Agree" onPress={handleAgree} />
      </View>
      <View style={{ marginTop: 10, marginBottom: 10 }}>
        <Button title="Cancel" onPress={handleCancel} color="red" />
      </View>

    </ScrollView>
  );
}
