import { useEffect, useState } from "react";
import { LOCALBACKEND } from "../../env";
import AsyncStorage from "@react-native-async-storage/async-storage";
import RSADecrypt from "../../services/decryptByRsaKey";
import DecryptWithAssetKey from "../../services/decryptByAssetKey";
import { WebView } from "react-native-webview";
import { View, Text, useWindowDimensions, ScrollView } from "react-native";
import RenderHTML from "react-native-render-html";

export default function NftView({ navigation, route }) {
  const [data, setData] = useState({});
  const [aesKey, setAesKey] = useState("");
  const [cid, setCid] = useState("");
  const [ipfsContent, setIpfsContent] = useState("");
  const [decryptedContent, setDecrypted] = useState("");
  const { width } = useWindowDimensions();

  useEffect(() => {
    fetchRequests();
  }, []);

  const fetchRequests = async () => {
    console.log("Asset code ", assetCode);
    const assetCode = route.params.assetcode;

    try {
      const assetUrl = LOCALBACKEND + `/practitioner/getassetdata/${assetCode}`;
      console.log(assetUrl);
      const response = await fetch(assetUrl);
      const json = await response.json();
      setData(json.data);
      setAesKey(data.key);
      setCid(data.cid);

      console.log(json.data);
      //get the content from the IPFS
      const ipfsContentCID = json.data.cid;
      const ipfsUrl = "https://ipfs.io/ipfs/" + ipfsContentCID;
      console.log(ipfsUrl);
      try {
        const ipfsResponse = await fetch(ipfsUrl);
        const ipfsText = await ipfsResponse.text();
        setIpfsContent(ipfsText);
        console.log(ipfsText);
        const decryptedIpfsContent = DecryptWithAssetKey(
          json.data.key,
          ipfsText
        );
        setDecrypted(decryptedIpfsContent);
        console.log(decryptedIpfsContent);
      } catch (errorWhenGGettingIPFSContent) {
        console.error(
          "Error when getting IPFS content :",
          errorWhenGGettingIPFSContent
        );
      }
    } catch (errorWhenGettingNftDetails) {
      console.log("Error when getting NFT details");
    }
  };

  return (
    <ScrollView>
      <RenderHTML contentWidth={width} source={{ html: decryptedContent }} />
    </ScrollView>
  );
}
