import { useEffect, useState } from "react";
import { LOCALBACKEND } from "../../env";
import { Button, StyleSheet, View, Text } from "react-native";
import AsyncStorage from "@react-native-async-storage/async-storage";
import EncryptWithServerKey from "../../services/encryptByServerKey";

export default function PatientRequests() {
  const [data, setData] = useState([]);

  useEffect(() => {
    fetchRequests();
  }, []);

  const fetchRequests = async () => {
    //get key from async storage
    try {
      const practitionerKey = await AsyncStorage.getItem(
        "practitionerStellarPublicKey"
      );
      try {
        const requestUrl =
          LOCALBACKEND +
          `/practitioner/practitionerrequests/${practitionerKey}`;

        console.log(requestUrl);

        const response = await fetch(requestUrl);
        const json = await response.json();
        setData(json.data);
      } catch (errorFetchingRequests) {
        console.log(
          "Error when fetching request data : ",
          errorFetchingRequests
        );
      }
    } catch (errorWhenGettingKey) {
      console.log(
        "Error when getting the public key from the async storage : ",
        errorWhenGettingKey
      );
    }
  };

  const renderItem = (item) => {
    return (
      <View key={item._id}>
        <Text>Key: {item.patient}</Text>
        <Button
          title="Accept"
          onPress={() => handleAcceptance(item, "Accepted")}
        ></Button>
        <Button
          title="Reject"
          onPress={() => handleAcceptance(item, "Rejected")}
        ></Button>
      </View>
    );
  };

  const handleAcceptance = async (item, status) => {
    //get the practitioner keys
    try {
      const practitionerKey = await AsyncStorage.getItem(
        "practitionerStellarPublicKey"
      );
      const practitionerSecretKey = await AsyncStorage.getItem(
        "practitionerStellarSecretKey"
      );

      const encryptedPractitionerKey = EncryptWithServerKey(practitionerKey);
      const encryptedPractitionerSeed = EncryptWithServerKey(
        practitionerSecretKey
      );
      const encryptedPatientKey = EncryptWithServerKey(item.patient);
      const encryptedStatus = EncryptWithServerKey(status);

      const acceptanceObj = {
        patient: encryptedPatientKey,
        practitionerkey: encryptedPractitionerKey,
        practitionerseed: encryptedPractitionerSeed,
        status: encryptedStatus,
      };

      const acceptanceUrl = LOCALBACKEND + "/practitioner/request";
      try {
        const acceptanceResponse = await fetch(acceptanceUrl, {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify(acceptanceObj),
        });

        const responseData = await acceptanceResponse.json();
        console.log(responseData);
      } catch (errorWhenSendingAcceptance) {
        console.log("Error when sending payload");
      }
    } catch (errorWheGettingKeyPair) {
      console.log("Getting key pair from async failed");
    }
  };

  return (
    <View style={styles.container}>{data.map((item) => renderItem(item))}</View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: "center",
    alignItems: "center",
  },
  text: {
    fontSize: 24,
    fontWeight: "bold",
  },
});
